AzureBlobPackageRepository class

Implemented types

Properties

connectionString String
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String name, String version, String pubspec, Uint8List package, {String? authorName}) Future<void>
override
listVersions(String name) Future<List<Version>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pubspec(String name, Version version) Future<Map<String, Object?>>
override
read(String name, Version version) Future<Stream<List<int>>>
override
sha256(String name, Version version) Future<String>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

connectionStringVarName → const String