PackageRepository class abstract interface

Implementers

Constructors

PackageRepository.concrete()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String name, String version, String pubspec, Uint8List package, {String? authorName}) Future<void>
listVersions(String name) Future<List<Version>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pubspec(String name, Version version) Future<Map<String, Object?>>
read(String name, Version version) Future<Stream<List<int>>>
sha256(String name, Version version) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

concreteConstructor PackageRepository Function()
no getter